summaryrefslogtreecommitdiff
path: root/tools
diff options
context:
space:
mode:
Diffstat (limited to 'tools')
-rw-r--r--tools/slang-test/test-context.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/slang-test/test-context.h b/tools/slang-test/test-context.h
index ad8a45042..aa27f7d96 100644
--- a/tools/slang-test/test-context.h
+++ b/tools/slang-test/test-context.h
@@ -159,8 +159,8 @@ class TestContext
/// TODO(JS): We could split the stdlib compilation from other actions, and have timeout specific for
/// that. To do this we could have a 'compileStdLib' RPC method.
///
- /// Current default is 20 seconds.
- Slang::Int connectionTimeOutInMs = 20 * 1000;
+ /// Current default is 60 seconds.
+ Slang::Int connectionTimeOutInMs = 60 * 1000;
void setThreadIndex(int index);
void setMaxTestRunnerThreadCount(int count);